@@ -233,7 +233,8 @@ seqformat <- function(data, var = NULL, from, to, compress = FALSE, nrep = NULL,
   converted <- switch(to,
     STS = msts,
     DSS = suppressMessages(STS_to_DSS(msts, missing = NA)),
-    SPS = suppressMessages(STS_to_SPS(msts, SPS.out, missing = NA)),
+  #  SPS = suppressMessages(STS_to_SPS(msts, SPS.out, missing = NA)),
+    SPS = suppressMessages(STS_to_SPS(msts, SPS.out, right=right, missing = NA)),
     SRS = STS_to_SRS(msts, nrep),
     TSE = STS_to_TSE(msts, uids, tevent),
     SPELL = STS_to_SPELL(ssts, pdata, pvar, with.missing))
