@@ -2,7 +2,7 @@
 ## Number of matching positions
 ## ============================
 
-seqmpos <- function(seq1, seq2, with.miss=FALSE) {
+seqmpos <- function(seq1, seq2, with.missing=FALSE) {
 
 	if (!inherits(seq1,"stslist") | !inherits(seq2,"stslist")) 
 		stop("sequences must be sequence objects")
@@ -13,7 +13,7 @@ seqmpos <- function(seq1, seq2, with.miss=FALSE) {
 	comp1 <- seq1!=attr(seq1,"void")
 	comp2 <- seq2!=attr(seq2,"void")
 
-	if (!with.miss) {
+	if (!with.missing) {
 		comp1 <- comp1 & seq1!=attr(seq1,"nr")
 		comp2 <- comp2 & seq2!=attr(seq2,"nr")
 	}
